@@ -184,6 +184,10 @@ sub _validate_request {
 
 Swagger2::Client - A client for talking to a Swagger powered server
 
+=head1 DEPRECATION WARNING
+
+See L<Swagger2>.
+
 =head1 DESCRIPTION
 
 L<Swagger2::Client> is a base class for autogenerated classes that can
